# Sentry-DingDing-maxbon

Fork `https://github.com/cench/sentry-10-dingding`

## 添加
告警内容添加tag环境信息

## 安装

```
# requirement.txt

sentry-dingding-maxbon
```

## 告警效果

![image](https://user-images.githubusercontent.com/3078554/139641752-8f5d7fba-5a4a-4b95-b61e-0df3736c759c.png)
